@@ -36,9 +36,9 @@
 #define TC_DEBUG 1
 
 #ifdef TC_DEBUG
-#define LOG(args...) g_log (G_LOG_DOMAIN, \
+#define LOG(format,args...) g_log (G_LOG_DOMAIN, \
                             G_LOG_LEVEL_MESSAGE, \
-                             "time_file: "##args)
+                            "time_file: " format, ##args)
 #else
 #define LOG(args...)
 #endif
@@ -129,26 +129,37 @@ static GtkWidget
 {
 	GtkWidget *vbox;
 	GtkWidget *option;
-	GtkMenu *menu, *m1, *m2;
+	GtkMenu *menu;
+	GtkWidget *m1, *m2;
+	GtkWidget *label;
 
-	vbox = gtk_vbox_new(FALSE, GNOME_PAD);
-	menu = gtk_menu_new ();
+	vbox = gtk_vbox_new (FALSE, GNOME_PAD);	
+
+	menu = GTK_MENU (gtk_menu_new ());
 
 	m1 = gtk_menu_item_new_with_label (_("Update PDA time"));
 	gtk_signal_connect (GTK_OBJECT (m1), "activate", 
 			    GTK_SIGNAL_FUNC (set_to_sync_to_pda), cfg);
-	gtk_menu_append (menu, GTK_WIDGET (m1));
+	gtk_menu_append (menu, m1);
 
 	m2 = gtk_menu_item_new_with_label (_("Update PC time"));
 	gtk_signal_connect (GTK_OBJECT (m2), "activate",
 			    GTK_SIGNAL_FUNC (set_to_sync_to_pc), cfg);
-	gtk_menu_append (menu, GTK_WIDGET (m2));
+	gtk_menu_append (menu, m2);
 
 	option = gtk_option_menu_new ();
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (option), GTK_WIDGET (menu));
 
-	vbox = gtk_vbox_new (FALSE, GNOME_PAD);	
 	gtk_box_pack_start (GTK_BOX (vbox), option, FALSE, FALSE, GNOME_PAD);
+	
+	label = gtk_label_new (_("Please note, that some versions of\n"
+				 "PalmOS<tm> may crash the PDA if the\n"
+				 "PDA's time is modifiedduring synchronization.\n"
+				 "\n"
+				 "A later version of this capplet will probably\n"
+				 "be able to check your PDA's OS version for this,\n"
+				 "but for now, it's trial and error."));
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, GNOME_PAD);
 
 	return vbox;
 }
@@ -248,11 +259,11 @@ conduit_load_gpilot_conduit (GPilotPilot *pilot)
 	gtk_object_set_data(GTK_OBJECT(retval),OBJ_DATA_CONFIG,cfg);
 	gtk_object_set_data(GTK_OBJECT(retval),OBJ_DATA_OLDCONFIG,cfg2);
 
-	gtk_signal_connect (retval, GNOME_PILOT_CONDUIT_STANDARD_SIGNAL_SYNCHRONIZE (synchronize), cfg);
-	gtk_signal_connect (retval, GNOME_PILOT_CONDUIT_SIGNAL_CREATE_SETTINGS_WINDOW (create_settings_window), NULL);
-	gtk_signal_connect (retval, GNOME_PILOT_CONDUIT_SIGNAL_DISPLAY_SETTINGS (display_settings), NULL);
-	gtk_signal_connect (retval, GNOME_PILOT_CONDUIT_SIGNAL_SAVE_SETTINGS (save_settings), NULL);
-	gtk_signal_connect (retval, GNOME_PILOT_CONDUIT_SIGNAL_REVERT_SETTINGS (revert_settings), NULL);
+	gtk_signal_connect (retval, "synchronize", (GtkSignalFunc)synchronize, cfg);
+	gtk_signal_connect (retval, "create_settings_window", (GtkSignalFunc)create_settings_window, NULL);
+	gtk_signal_connect (retval, "display_settings", (GtkSignalFunc)display_settings, NULL);
+	gtk_signal_connect (retval, "save_settings", (GtkSignalFunc)save_settings, NULL);
+	gtk_signal_connect (retval, "revert_settings", (GtkSignalFunc)revert_settings, NULL);
 
 	return GNOME_PILOT_CONDUIT (retval);
 }
